@@ -17,16 +17,17 @@
 
 package org.apache.logging.log4j.util;
 
-import java.io.Console;
+import org.junit.Before;
+import org.junit.Test;
+
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 import java.util.Map;
 import java.util.Properties;
 
-import org.junit.Before;
-import org.junit.Test;
-
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 
 /**
  *
@@ -82,14 +83,29 @@ public class PropertiesUtilTest {
     @Test
     public void testGetMappedProperty_sun_stdout_encoding() {
         final PropertiesUtil pu = new PropertiesUtil(System.getProperties());
-        Charset expected = System.console() == null ? Charset.defaultCharset() : StandardCharsets.UTF_8;
+        final Charset expected = System.console() == null ? Charset.defaultCharset() : StandardCharsets.UTF_8;
         assertEquals(expected, pu.getCharsetProperty("sun.stdout.encoding"));
     }
 
     @Test
     public void testGetMappedProperty_sun_stderr_encoding() {
         final PropertiesUtil pu = new PropertiesUtil(System.getProperties());
-        Charset expected = System.console() == null ? Charset.defaultCharset() : StandardCharsets.UTF_8;
+        final Charset expected = System.console() == null ? Charset.defaultCharset() : StandardCharsets.UTF_8;
         assertEquals(expected, pu.getCharsetProperty("sun.err.encoding"));
     }
+
+    @Test
+    public void testNonStringSystemProperties() {
+        final Object key1 = "1";
+        final Object key2 = new Object();
+        System.getProperties().put(key1, new Object());
+        System.getProperties().put(key2, "value-2");
+        try {
+            final PropertiesUtil util = new PropertiesUtil(new Properties());
+            assertNull(util.getStringProperty("1"));
+        } finally {
+            System.getProperties().remove(key1);
+            System.getProperties().remove(key2);
+        }
+    }
 }
