@@ -26,6 +26,7 @@ import org.apache.logging.log4j.core.Filter;
 import org.apache.logging.log4j.core.Layout;
 import org.apache.logging.log4j.core.LogEvent;
 import org.apache.logging.log4j.core.config.Configuration;
+import org.apache.logging.log4j.core.config.Property;
 import org.apache.logging.log4j.core.config.plugins.PluginBuilderAttribute;
 import org.apache.logging.log4j.core.config.plugins.PluginConfiguration;
 import org.apache.logging.log4j.core.config.plugins.PluginElement;
@@ -41,15 +42,15 @@ import org.apache.logging.log4j.core.util.Integers;
 public abstract class AbstractAppender extends AbstractFilterable implements Appender {
 
     /**
-     * Subclasses can extend this abstract Builder. 
-     * 
+     * Subclasses can extend this abstract Builder.
+     *
      * @param <B> The type to build.
      */
     public abstract static class Builder<B extends Builder<B>> extends AbstractFilterable.Builder<B> {
 
         @PluginBuilderAttribute
         private boolean ignoreExceptions = true;
-        
+
         @PluginElement("Layout")
         private Layout<? extends Serializable> layout;
 
@@ -60,31 +61,16 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
         @PluginConfiguration
         private Configuration configuration;
 
-        public String getName() {
-            return name;
-        }
-
-        public boolean isIgnoreExceptions() {
-            return ignoreExceptions;
+        public Configuration getConfiguration() {
+            return configuration;
         }
 
         public Layout<? extends Serializable> getLayout() {
             return layout;
         }
 
-        public B withName(final String name) {
-            this.name = name;
-            return asBuilder();
-        }
-
-        public B withIgnoreExceptions(final boolean ignoreExceptions) {
-            this.ignoreExceptions = ignoreExceptions;
-            return asBuilder();
-        }
-
-        public B withLayout(final Layout<? extends Serializable> layout) {
-            this.layout = layout;
-            return asBuilder();
+        public String getName() {
+            return name;
         }
 
         public Layout<? extends Serializable> getOrCreateLayout() {
@@ -93,7 +79,7 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
             }
             return layout;
         }
-        
+
         public Layout<? extends Serializable> getOrCreateLayout(final Charset charset) {
             if (layout == null) {
                 return PatternLayout.newBuilder().withCharset(charset).build();
@@ -101,6 +87,30 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
             return layout;
         }
 
+        public boolean isIgnoreExceptions() {
+            return ignoreExceptions;
+        }
+
+        public B setConfiguration(final Configuration configuration) {
+            this.configuration = configuration;
+            return asBuilder();
+        }
+
+        public B setIgnoreExceptions(final boolean ignoreExceptions) {
+            this.ignoreExceptions = ignoreExceptions;
+            return asBuilder();
+        }
+
+        public B setLayout(final Layout<? extends Serializable> layout) {
+            this.layout = layout;
+            return asBuilder();
+        }
+
+        public B setName(final String name) {
+            this.name = name;
+            return asBuilder();
+        }
+
         /**
          * @deprecated Use {@link #setConfiguration(Configuration)}
          */
@@ -110,48 +120,30 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
             return asBuilder();
         }
 
-        public B setConfiguration(final Configuration configuration) {
-            this.configuration = configuration;
-            return asBuilder();
+        /**
+         * @deprecated use {@link #setIgnoreExceptions(boolean)}.
+         */
+        @Deprecated
+        public B withIgnoreExceptions(final boolean ignoreExceptions) {
+            return setIgnoreExceptions(ignoreExceptions);
         }
 
-        public Configuration getConfiguration() {
-            return configuration;
+        /**
+         * @deprecated use {@link #setLayout(Layout)}.
+         */
+        @Deprecated
+        public B withLayout(final Layout<? extends Serializable> layout) {
+            return setLayout(layout);
         }
-        
-    }
-    
-    private final String name;
-    private final boolean ignoreExceptions;
-    private final Layout<? extends Serializable> layout;
-    private ErrorHandler handler = new DefaultErrorHandler(this);
 
-    /**
-     * Constructor that defaults to suppressing exceptions.
-     * 
-     * @param name The Appender name.
-     * @param filter The Filter to associate with the Appender.
-     * @param layout The layout to use to format the event.
-     */
-    protected AbstractAppender(final String name, final Filter filter, final Layout<? extends Serializable> layout) {
-        this(name, filter, layout, true);
-    }
+        /**
+         * @deprecated use {@link #setName(String)}.
+         */
+        @Deprecated
+        public B withName(final String name) {
+            return setName(name);
+        }
 
-    /**
-     * Constructor.
-     * 
-     * @param name The Appender name.
-     * @param filter The Filter to associate with the Appender.
-     * @param layout The layout to use to format the event.
-     * @param ignoreExceptions If true, exceptions will be logged and suppressed. If false errors will be logged and
-     *            then passed to the application.
-     */
-    protected AbstractAppender(final String name, final Filter filter, final Layout<? extends Serializable> layout,
-            final boolean ignoreExceptions) {
-        super(filter);
-        this.name = Objects.requireNonNull(name, "name");
-        this.layout = layout;
-        this.ignoreExceptions = ignoreExceptions;
     }
 
     public static int parseInt(final String s, final int defaultValue) {
@@ -162,10 +154,62 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
             return defaultValue;
         }
     }
+    private final String name;
+    private final boolean ignoreExceptions;
+    private final Layout<? extends Serializable> layout;
+
+    private ErrorHandler handler = new DefaultErrorHandler(this);
+
+    /**
+     * Constructor that defaults to suppressing exceptions.
+     *
+     * @param name The Appender name.
+     * @param filter The Filter to associate with the Appender.
+     * @param layout The layout to use to format the event.
+     * @deprecated Use {@link #AbstractAppender(String, Filter, Layout, boolean, Property[])}.
+     */
+    @Deprecated
+    protected AbstractAppender(final String name, final Filter filter, final Layout<? extends Serializable> layout) {
+        this(name, filter, layout, true, Property.EMPTY_ARRAY);
+    }
+
+    /**
+     * Constructor.
+     *
+     * @param name The Appender name.
+     * @param filter The Filter to associate with the Appender.
+     * @param layout The layout to use to format the event.
+     * @param ignoreExceptions If true, exceptions will be logged and suppressed. If false errors will be logged and
+     *            then passed to the application.
+     * @deprecated Use {@link #AbstractAppender(String, Filter, Layout, boolean, Property[])}
+     */
+    @Deprecated
+    protected AbstractAppender(final String name, final Filter filter, final Layout<? extends Serializable> layout,
+            final boolean ignoreExceptions) {
+        this(name, filter, layout, ignoreExceptions, Property.EMPTY_ARRAY);
+    }
+
+    /**
+     * Constructor.
+     *
+     * @param name The Appender name.
+     * @param filter The Filter to associate with the Appender.
+     * @param layout The layout to use to format the event.
+     * @param ignoreExceptions If true, exceptions will be logged and suppressed. If false errors will be logged and
+     *            then passed to the application.
+     * @since 2.11.2
+     */
+    protected AbstractAppender(final String name, final Filter filter, final Layout<? extends Serializable> layout,
+            final boolean ignoreExceptions, final Property[] properties) {
+        super(filter, properties);
+        this.name = Objects.requireNonNull(name, "name");
+        this.layout = layout;
+        this.ignoreExceptions = ignoreExceptions;
+    }
 
     /**
      * Handle an error with a message using the {@link ErrorHandler} configured for this Appender.
-     * 
+     *
      * @param msg The message.
      */
     public void error(final String msg) {
@@ -175,7 +219,7 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
     /**
      * Handle an error with a message, exception, and a logging event, using the {@link ErrorHandler} configured for
      * this Appender.
-     * 
+     *
      * @param msg The message.
      * @param event The LogEvent.
      * @param t The Throwable.
@@ -186,7 +230,7 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
 
     /**
      * Handle an error with a message and an exception using the {@link ErrorHandler} configured for this Appender.
-     * 
+     *
      * @param msg The message.
      * @param t The Throwable.
      */
@@ -196,7 +240,7 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
 
     /**
      * Returns the ErrorHandler, if any.
-     * 
+     *
      * @return The ErrorHandler.
      */
     @Override
@@ -206,7 +250,7 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
 
     /**
      * Returns the Layout for the appender.
-     * 
+     *
      * @return The Layout used to format the event.
      */
     @Override
@@ -216,7 +260,7 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
 
     /**
      * Returns the name of the Appender.
-     * 
+     *
      * @return The name of the Appender.
      */
     @Override
@@ -237,13 +281,14 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
 
     /**
      * The handler must be set before the appender is started.
-     * 
+     *
      * @param handler The ErrorHandler to use.
      */
     @Override
     public void setHandler(final ErrorHandler handler) {
         if (handler == null) {
             LOGGER.error("The handler cannot be set to null");
+            return;
         }
         if (isStarted()) {
             LOGGER.error("The handler cannot be changed once the appender is started");
@@ -252,6 +297,17 @@ public abstract class AbstractAppender extends AbstractFilterable implements App
         this.handler = handler;
     }
 
+    /**
+     * Serializes the given event using the appender's layout if present.
+     *
+     * @param event
+     *            the event to serialize.
+     * @return the serialized event or null if no layout is present.
+     */
+    protected Serializable toSerializable(final LogEvent event) {
+        return layout != null ? layout.toSerializable(event) : null;
+    }
+
     @Override
     public String toString() {
         return name;
