@@ -18,27 +18,24 @@
 package org.apache.logging.log4j.core.appender.mom.kafka;
 
 import java.io.Serializable;
-import java.nio.charset.StandardCharsets;
 import java.util.Objects;
+import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
 
+import org.apache.logging.log4j.core.AbstractLifeCycle;
 import org.apache.logging.log4j.core.Appender;
 import org.apache.logging.log4j.core.Filter;
 import org.apache.logging.log4j.core.Layout;
 import org.apache.logging.log4j.core.LogEvent;
 import org.apache.logging.log4j.core.appender.AbstractAppender;
-import org.apache.logging.log4j.core.appender.AppenderLoggingException;
 import org.apache.logging.log4j.core.config.Configuration;
 import org.apache.logging.log4j.core.config.Node;
 import org.apache.logging.log4j.core.config.Property;
 import org.apache.logging.log4j.core.config.plugins.Plugin;
 import org.apache.logging.log4j.core.config.plugins.PluginAttribute;
 import org.apache.logging.log4j.core.config.plugins.PluginBuilderFactory;
-import org.apache.logging.log4j.core.config.plugins.PluginConfiguration;
-import org.apache.logging.log4j.core.config.plugins.PluginElement;
-import org.apache.logging.log4j.core.config.plugins.validation.constraints.Required;
 import org.apache.logging.log4j.core.layout.SerializedLayout;
-import org.apache.logging.log4j.core.util.StringEncoder;
 
 /**
  * Sends log events to an Apache Kafka topic.
@@ -53,57 +50,67 @@ public final class KafkaAppender extends AbstractAppender {
     public static class Builder<B extends Builder<B>> extends AbstractAppender.Builder<B>
             implements org.apache.logging.log4j.core.util.Builder<KafkaAppender> {
 
-        @PluginAttribute("topic") 
+        @PluginAttribute("topic")
         private String topic;
-        
+
+        @PluginAttribute("key")
+        private String key;
+
         @PluginAttribute(value = "syncSend", defaultBoolean = true)
         private boolean syncSend;
 
-        @PluginElement("Properties") 
-        private Property[] properties;
-
         @SuppressWarnings("resource")
         @Override
         public KafkaAppender build() {
-            final KafkaManager kafkaManager = new KafkaManager(getConfiguration().getLoggerContext(), getName(), topic, syncSend, properties);
-            return new KafkaAppender(getName(), getLayout(), getFilter(), isIgnoreExceptions(), kafkaManager);
+            final Layout<? extends Serializable> layout = getLayout();
+            if (layout == null) {
+                AbstractLifeCycle.LOGGER.error("No layout provided for KafkaAppender");
+                return null;
+            }
+            final KafkaManager kafkaManager = new KafkaManager(getConfiguration().getLoggerContext(), getName(), topic,
+                    syncSend, getPropertyArray(), key);
+            return new KafkaAppender(getName(), layout, getFilter(), isIgnoreExceptions(), kafkaManager,
+                    getPropertyArray());
         }
 
         public String getTopic() {
             return topic;
         }
 
-        public Property[] getProperties() {
-            return properties;
+        public boolean isSyncSend() {
+            return syncSend;
         }
 
-        public B setTopic(String topic) {
+        public B setTopic(final String topic) {
             this.topic = topic;
             return asBuilder();
         }
 
-        public B setSyncSend(boolean syncSend) {
+        public B setSyncSend(final boolean syncSend) {
             this.syncSend = syncSend;
             return asBuilder();
         }
 
-        public B setProperties(Property[] properties) {
-            this.properties = properties;
-            return asBuilder();
-        }
     }
-    
+
     @Deprecated
     public static KafkaAppender createAppender(
-            @PluginElement("Layout") final Layout<? extends Serializable> layout,
-            @PluginElement("Filter") final Filter filter,
-            @Required(message = "No name provided for KafkaAppender") @PluginAttribute("name") final String name,
-            @PluginAttribute(value = "ignoreExceptions", defaultBoolean = true) final boolean ignoreExceptions,
-            @Required(message = "No topic provided for KafkaAppender") @PluginAttribute("topic") final String topic,
-            @PluginElement("Properties") final Property[] properties,
-            @PluginConfiguration final Configuration configuration) {
-        final KafkaManager kafkaManager = new KafkaManager(configuration.getLoggerContext(), name, topic, true, properties);
-        return new KafkaAppender(name, layout, filter, ignoreExceptions, kafkaManager);
+            final Layout<? extends Serializable> layout,
+            final Filter filter,
+            final String name,
+            final boolean ignoreExceptions,
+            final String topic,
+            final Property[] properties,
+            final Configuration configuration,
+            final String key) {
+
+        if (layout == null) {
+            AbstractLifeCycle.LOGGER.error("No layout provided for KafkaAppender");
+            return null;
+        }
+        final KafkaManager kafkaManager =
+                new KafkaManager(configuration.getLoggerContext(), name, topic, true, properties, key);
+        return new KafkaAppender(name, layout, filter, ignoreExceptions, kafkaManager, null);
     }
 
     /**
@@ -118,8 +125,8 @@ public final class KafkaAppender extends AbstractAppender {
     private final KafkaManager manager;
 
     private KafkaAppender(final String name, final Layout<? extends Serializable> layout, final Filter filter,
-            final boolean ignoreExceptions, final KafkaManager manager) {
-        super(name, filter, layout, ignoreExceptions);
+            final boolean ignoreExceptions, final KafkaManager manager, final Property[] properties) {
+        super(name, filter, layout, ignoreExceptions, properties);
         this.manager = Objects.requireNonNull(manager, "manager");
     }
 
@@ -129,29 +136,28 @@ public final class KafkaAppender extends AbstractAppender {
             LOGGER.warn("Recursive logging from [{}] for appender [{}].", event.getLoggerName(), getName());
         } else {
             try {
-                final Layout<? extends Serializable> layout = getLayout();
-                byte[] data;
-                if (layout != null) {
-                    if (layout instanceof SerializedLayout) {
-                        final byte[] header = layout.getHeader();
-                        final byte[] body = layout.toByteArray(event);
-                        data = new byte[header.length + body.length];
-                        System.arraycopy(header, 0, data, 0, header.length);
-                        System.arraycopy(body, 0, data, header.length, body.length);
-                    } else {
-                        data = layout.toByteArray(event);
-                    }
-                } else {
-                    data = StringEncoder.toBytes(event.getMessage().getFormattedMessage(), StandardCharsets.UTF_8);
-                }
-                manager.send(data);
+                tryAppend(event);
             } catch (final Exception e) {
-                LOGGER.error("Unable to write to Kafka [{}] for appender [{}].", manager.getName(), getName(), e);
-                throw new AppenderLoggingException("Unable to write to Kafka in appender: " + e.getMessage(), e);
+                error("Unable to write to Kafka in appender [" + getName() + "]", event, e);
             }
         }
     }
 
+    private void tryAppend(final LogEvent event) throws ExecutionException, InterruptedException, TimeoutException {
+        final Layout<? extends Serializable> layout = getLayout();
+        byte[] data;
+        if (layout instanceof SerializedLayout) {
+            final byte[] header = layout.getHeader();
+            final byte[] body = layout.toByteArray(event);
+            data = new byte[header.length + body.length];
+            System.arraycopy(header, 0, data, 0, header.length);
+            System.arraycopy(body, 0, data, header.length, body.length);
+        } else {
+            data = layout.toByteArray(event);
+        }
+        manager.send(data);
+    }
+
     @Override
     public void start() {
         super.start();
