@@ -90,10 +90,10 @@ public class DefaultRolloverStrategy extends AbstractRolloverStrategy {
     public static class Builder implements org.apache.logging.log4j.core.util.Builder<DefaultRolloverStrategy> {
         @PluginBuilderAttribute("max")
         private String max;
-        
+
         @PluginBuilderAttribute("min")
         private String min;
-        
+
         @PluginBuilderAttribute("fileIndex")
         private String fileIndex;
 
@@ -143,7 +143,7 @@ public class DefaultRolloverStrategy extends AbstractRolloverStrategy {
             }
             final int compressionLevel = Integers.parseInt(compressionLevelStr, Deflater.DEFAULT_COMPRESSION);
             // The config object can be null when this object is built programmatically.
-            StrSubstitutor nonNullStrSubstitutor = config != null ? config.getStrSubstitutor() : new StrSubstitutor();
+            final StrSubstitutor nonNullStrSubstitutor = config != null ? config.getStrSubstitutor() : new StrSubstitutor();
 			return new DefaultRolloverStrategy(minIndex, maxIndex, useMax, compressionLevel, nonNullStrSubstitutor,
                     customActions, stopCustomActionsOnError, tempCompressedFilePattern);
         }
@@ -260,7 +260,7 @@ public class DefaultRolloverStrategy extends AbstractRolloverStrategy {
 
         /**
          * Defines configuration.
-         * 
+         *
          * @param config The Configuration.
          * @return This builder for chaining convenience
          */
@@ -517,9 +517,11 @@ public class DefaultRolloverStrategy extends AbstractRolloverStrategy {
     @Override
     public RolloverDescription rollover(final RollingFileManager manager) throws SecurityException {
         int fileIndex;
+		final StringBuilder buf = new StringBuilder(255);
         if (minIndex == Integer.MIN_VALUE) {
             final SortedMap<Integer, Path> eligibleFiles = getEligibleFiles(manager);
             fileIndex = eligibleFiles.size() > 0 ? eligibleFiles.lastKey() + 1 : 1;
+			manager.getPatternProcessor().formatFileName(strSubstitutor, buf, fileIndex);
         } else {
             if (maxIndex < 0) {
                 return null;
@@ -529,13 +531,13 @@ public class DefaultRolloverStrategy extends AbstractRolloverStrategy {
             if (fileIndex < 0) {
                 return null;
             }
+			manager.getPatternProcessor().formatFileName(strSubstitutor, buf, fileIndex);
             if (LOGGER.isTraceEnabled()) {
                 final double durationMillis = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - startNanos);
                 LOGGER.trace("DefaultRolloverStrategy.purge() took {} milliseconds", durationMillis);
             }
         }
-        final StringBuilder buf = new StringBuilder(255);
-        manager.getPatternProcessor().formatFileName(strSubstitutor, buf, fileIndex);
+
         final String currentFileName = manager.getFileName();
 
         String renameTo = buf.toString();
