@@ -55,6 +55,7 @@ public class PatternProcessor {
 
     private long prevFileTime = 0;
     private long nextFileTime = 0;
+    private long currentFileTime = 0;
 
     private RolloverFrequency frequency = null;
 
@@ -78,7 +79,7 @@ public class PatternProcessor {
         final PatternParser parser = createPatternParser();
         final List<PatternConverter> converters = new ArrayList<>();
         final List<FormattingInfo> fields = new ArrayList<>();
-        parser.parse(pattern, converters, fields, false, false);
+        parser.parse(pattern, converters, fields, false, false, false);
         final FormattingInfo[] infoArray = new FormattingInfo[fields.size()];
         patternFields = fields.toArray(infoArray);
         final ArrayPatternConverter[] converterArray = new ArrayPatternConverter[converters.size()];
@@ -92,11 +93,33 @@ public class PatternProcessor {
         }
     }
 
+    /**
+     * Copy constructor with another pattern as source.
+     *
+     * @param pattern  The file pattern.
+     * @param copy Source pattern processor
+     */
+    public PatternProcessor(final String pattern, final PatternProcessor copy) {
+        this(pattern);
+        this.prevFileTime = copy.prevFileTime;
+        this.nextFileTime = copy.nextFileTime;
+        this.currentFileTime = copy.currentFileTime;
+    }
+
+    public long getCurrentFileTime() {
+        return currentFileTime;
+    }
+
+    public void setCurrentFileTime(final long currentFileTime) {
+        this.currentFileTime = currentFileTime;
+    }
+
     public long getPrevFileTime() {
         return prevFileTime;
     }
 
     public void setPrevFileTime(final long prevFileTime) {
+        LOGGER.debug("Setting prev file time to {}", new Date(prevFileTime));
         this.prevFileTime = prevFileTime;
     }
 
@@ -190,7 +213,9 @@ public class PatternProcessor {
     }
 
     public void updateTime() {
-        prevFileTime = nextFileTime;
+    	if (nextFileTime != 0) {
+			prevFileTime = nextFileTime;
+		}
     }
 
     private long debugGetNextTime(final long nextTime) {
@@ -215,8 +240,11 @@ public class PatternProcessor {
      * @param buf string buffer to which formatted file name is appended, may not be null.
      * @param obj object to be evaluated in formatting, may not be null.
      */
-    public final void formatFileName(final StringBuilder buf, final Object obj) {
-        final long time = prevFileTime == 0 ? System.currentTimeMillis() : prevFileTime;
+    public final void formatFileName(final StringBuilder buf, final boolean useCurrentTime, final Object obj) {
+        long time = useCurrentTime ? currentFileTime : prevFileTime;
+        if (time == 0) {
+            time = System.currentTimeMillis();
+        }
         formatFileName(buf, new Date(time), obj);
     }
 
@@ -227,9 +255,23 @@ public class PatternProcessor {
      * @param obj object to be evaluated in formatting, may not be null.
      */
     public final void formatFileName(final StrSubstitutor subst, final StringBuilder buf, final Object obj) {
+        formatFileName(subst, buf, false, obj);
+    }
+
+    /**
+     * Formats file name.
+     * @param subst The StrSubstitutor.
+     * @param buf string buffer to which formatted file name is appended, may not be null.
+     * @param obj object to be evaluated in formatting, may not be null.
+     */
+    public final void formatFileName(final StrSubstitutor subst, final StringBuilder buf, final boolean useCurrentTime,
+                                     final Object obj) {
         // LOG4J2-628: we deliberately use System time, not the log4j.Clock time
         // for creating the file name of rolled-over files.
-        final long time = prevFileTime == 0 ? System.currentTimeMillis() : prevFileTime;
+        LOGGER.debug("Formatting file name. useCurrentTime={}. currentFileTime={}, prevFileTime={}",
+            useCurrentTime, currentFileTime, prevFileTime);
+        final long time = useCurrentTime ? currentFileTime != 0 ? currentFileTime : System.currentTimeMillis() :
+                prevFileTime != 0 ? prevFileTime : System.currentTimeMillis();
         formatFileName(buf, new Date(time), obj);
         final LogEvent event = new Log4jLogEvent.Builder().setTimeMillis(time).build();
         final String fileName = subst.replace(event, buf);
@@ -306,4 +348,5 @@ public class PatternProcessor {
     public long getNextFileTime() {
         return nextFileTime;
     }
+
 }
