@@ -39,6 +39,7 @@ import org.apache.logging.log4j.core.config.plugins.util.PluginType;
 import org.apache.logging.log4j.core.lookup.Interpolator;
 import org.apache.logging.log4j.core.lookup.StrSubstitutor;
 import org.apache.logging.log4j.core.util.FileUtils;
+import org.apache.logging.log4j.core.util.Loader;
 import org.apache.logging.log4j.core.util.NetUtils;
 import org.apache.logging.log4j.core.util.ReflectionUtil;
 import org.apache.logging.log4j.status.StatusLogger;
@@ -173,7 +174,7 @@ public abstract class ConfigurationFactory extends ConfigurationBuilderFactory {
 
     private static void addFactory(final Collection<ConfigurationFactory> list, final String factoryClass) {
         try {
-            addFactory(list, LoaderUtil.loadClass(factoryClass).asSubclass(ConfigurationFactory.class));
+            addFactory(list, Loader.loadClass(factoryClass).asSubclass(ConfigurationFactory.class));
         } catch (final Exception ex) {
             LOGGER.error("Unable to load class {}", factoryClass, ex);
         }
@@ -389,10 +390,12 @@ public abstract class ConfigurationFactory extends ConfigurationBuilderFactory {
             if (config != null) {
                 return config;
             }
-            LOGGER.error("No log4j2 configuration file found. " +
-                    "Using default configuration: logging only errors to the console. " +
+            LOGGER.error("No Log4j 2 configuration file found. " +
+                    "Using default configuration (logging only errors to the console), " +
+                    "or user programmatically provided configurations. " +
                     "Set system property 'log4j2.debug' " +
-                    "to show Log4j2 internal initialization logging.");
+                    "to show Log4j 2 internal initialization logging. " +
+                    "See https://logging.apache.org/log4j/2.x/manual/configuration.html for instructions on how to configure Log4j 2");
             return new DefaultConfiguration();
         }
 
