@@ -30,6 +30,9 @@ import org.apache.logging.log4j.core.Appender;
 import org.apache.logging.log4j.core.Core;
 import org.apache.logging.log4j.core.Filter;
 import org.apache.logging.log4j.core.LogEvent;
+import org.apache.logging.log4j.core.LoggerContext;
+import org.apache.logging.log4j.core.async.AsyncLoggerConfig;
+import org.apache.logging.log4j.core.async.AsyncLoggerContext;
 import org.apache.logging.log4j.core.async.AsyncLoggerContextSelector;
 import org.apache.logging.log4j.core.config.plugins.Plugin;
 import org.apache.logging.log4j.core.config.plugins.PluginAttribute;
@@ -45,8 +48,8 @@ import org.apache.logging.log4j.core.impl.ReusableLogEventFactory;
 import org.apache.logging.log4j.core.lookup.StrSubstitutor;
 import org.apache.logging.log4j.core.util.Booleans;
 import org.apache.logging.log4j.core.util.Constants;
+import org.apache.logging.log4j.core.util.Loader;
 import org.apache.logging.log4j.message.Message;
-import org.apache.logging.log4j.util.LoaderUtil;
 import org.apache.logging.log4j.util.PerformanceSensitive;
 import org.apache.logging.log4j.util.PropertiesUtil;
 import org.apache.logging.log4j.util.Strings;
@@ -78,7 +81,7 @@ public class LoggerConfig extends AbstractFilterable {
         final String factory = PropertiesUtil.getProperties().getStringProperty(Constants.LOG4J_LOG_EVENT_FACTORY);
         if (factory != null) {
             try {
-                final Class<?> clazz = LoaderUtil.loadClass(factory);
+                final Class<?> clazz = Loader.loadClass(factory);
                 if (clazz != null && LogEventFactory.class.isAssignableFrom(clazz)) {
                     LOG_EVENT_FACTORY = (LogEventFactory) clazz.newInstance();
                 }
@@ -265,7 +268,7 @@ public class LoggerConfig extends AbstractFilterable {
      * @return the logging Level.
      */
     public Level getLevel() {
-        return level == null ? parent.getLevel() : level;
+        return level == null ? parent == null ? Level.ERROR : parent.getLevel() : level;
     }
 
     /**
@@ -400,7 +403,7 @@ public class LoggerConfig extends AbstractFilterable {
         }
         final LogEvent logEvent = logEventFactory.createEvent(loggerName, marker, fqcn, level, data, props, t);
         try {
-            log(logEvent);
+            log(logEvent, LoggerConfigPredicate.ALL);
         } finally {
             // LOG4J2-1583 prevent scrambled logs when logging calls are nested (logging in toString())
             ReusableLogEventFactory.release(logEvent);
@@ -413,8 +416,19 @@ public class LoggerConfig extends AbstractFilterable {
      * @param event The log event.
      */
     public void log(final LogEvent event) {
+        log(event, LoggerConfigPredicate.ALL);
+    }
+
+    /**
+     * Logs an event.
+     *
+     * @param event The log event.
+     * @param predicate predicate for which LoggerConfig instances to append to.
+     *                  A null value is equivalent to a true predicate.
+     */
+    protected void log(final LogEvent event, final LoggerConfigPredicate predicate) {
         if (!isFiltered(event)) {
-            processLogEvent(event);
+            processLogEvent(event, predicate);
         }
     }
 
@@ -428,15 +442,17 @@ public class LoggerConfig extends AbstractFilterable {
         return reliabilityStrategy;
     }
 
-    private void processLogEvent(final LogEvent event) {
+    private void processLogEvent(final LogEvent event, final LoggerConfigPredicate predicate) {
         event.setIncludeLocation(isIncludeLocation());
-        callAppenders(event);
-        logParent(event);
+        if (predicate.allow(this)) {
+            callAppenders(event);
+        }
+        logParent(event, predicate);
     }
 
-    private void logParent(final LogEvent event) {
+    private void logParent(final LogEvent event, final LoggerConfigPredicate predicate) {
         if (additive && parent != null) {
-            parent.log(event);
+            parent.log(event, predicate);
         }
     }
 
@@ -489,7 +505,7 @@ public class LoggerConfig extends AbstractFilterable {
         final boolean additive = Booleans.parseBoolean(additivity, true);
 
         return new LoggerConfig(name, appenderRefs, filter, level, additive, properties, config,
-                includeLocation(includeLocation));
+                includeLocation(includeLocation, config));
     }
 
     /**
@@ -521,19 +537,38 @@ public class LoggerConfig extends AbstractFilterable {
     ) {
         final String name = loggerName.equals(ROOT) ? Strings.EMPTY : loggerName;
         return new LoggerConfig(name, Arrays.asList(refs), filter, level, additivity, properties, config,
-            includeLocation(includeLocation));
+            includeLocation(includeLocation, config));
+    }
+
+    /**
+     * @deprecated Please use {@link #includeLocation(String, Configuration)}
+     */
+    @Deprecated
+    protected static boolean includeLocation(final String includeLocationConfigValue) {
+        return includeLocation(includeLocationConfigValue, null);
     }
 
     // Note: for asynchronous loggers, includeLocation default is FALSE,
     // for synchronous loggers, includeLocation default is TRUE.
-    protected static boolean includeLocation(final String includeLocationConfigValue) {
+    protected static boolean includeLocation(final String includeLocationConfigValue, final Configuration configuration) {
         if (includeLocationConfigValue == null) {
-            final boolean sync = !AsyncLoggerContextSelector.isSelected();
-            return sync;
+            LoggerContext context = null;
+            if (configuration != null) {
+                context = configuration.getLoggerContext();
+            }
+            if (context != null) {
+                return !(context instanceof AsyncLoggerContext);
+            } else {
+                return !AsyncLoggerContextSelector.isSelected();
+            }
         }
         return Boolean.parseBoolean(includeLocationConfigValue);
     }
 
+    protected final boolean hasAppenders() {
+        return !appenders.isEmpty();
+    }
+
     /**
      * The root Logger.
      */
@@ -556,8 +591,30 @@ public class LoggerConfig extends AbstractFilterable {
             final boolean additive = Booleans.parseBoolean(additivity, true);
 
             return new LoggerConfig(LogManager.ROOT_LOGGER_NAME, appenderRefs, filter, actualLevel, additive,
-                    properties, config, includeLocation(includeLocation));
+                    properties, config, includeLocation(includeLocation, config));
         }
     }
 
+    protected enum LoggerConfigPredicate {
+        ALL() {
+            @Override
+            boolean allow(final LoggerConfig config) {
+                return true;
+            }
+        },
+        ASYNCHRONOUS_ONLY() {
+            @Override
+            boolean allow(final LoggerConfig config) {
+                return config instanceof AsyncLoggerConfig;
+            }
+        },
+        SYNCHRONOUS_ONLY() {
+            @Override
+            boolean allow(final LoggerConfig config) {
+                return !ASYNCHRONOUS_ONLY.allow(config);
+            }
+        };
+
+        abstract boolean allow(LoggerConfig config);
+    }
 }
