@@ -19,24 +19,27 @@ package org.apache.logging.log4j.core.impl;
 import java.lang.invoke.MethodHandle;
 import java.lang.invoke.MethodHandles;
 import java.lang.invoke.MethodType;
+import java.util.Map;
+import java.util.Map.Entry;
 
 import org.apache.logging.log4j.core.ContextDataInjector;
 import org.apache.logging.log4j.core.LogEvent;
-import org.apache.logging.log4j.util.LoaderUtil;
+import org.apache.logging.log4j.core.util.Loader;
+import org.apache.logging.log4j.util.IndexedStringMap;
 import org.apache.logging.log4j.util.PropertiesUtil;
+import org.apache.logging.log4j.util.ReadOnlyStringMap;
 import org.apache.logging.log4j.util.SortedArrayStringMap;
 import org.apache.logging.log4j.util.StringMap;
 
 /**
- * Factory for creating the StringMap instances used to initialize LogEvents'
- * {@linkplain LogEvent#getContextData() context data}. When context data is
- * {@linkplain ContextDataInjector injected} into the log event, these StringMap
+ * Factory for creating the StringMap instances used to initialize LogEvents' {@linkplain LogEvent#getContextData()
+ * context data}. When context data is {@linkplain ContextDataInjector injected} into the log event, these StringMap
  * instances may be either populated with key-value pairs from the context, or completely replaced altogether.
  * <p>
  * By default returns {@code SortedArrayStringMap} objects. Can be configured by setting system property
- * {@code "log4j2.ContextData"} to the fully qualified class name of a class implementing the
- * {@code StringMap} interface. The class must have a public default constructor, and if possible should also have a
- * public constructor that takes a single {@code int} argument for the initial capacity.
+ * {@code "log4j2.ContextData"} to the fully qualified class name of a class implementing the {@code StringMap}
+ * interface. The class must have a public default constructor, and if possible should also have a public constructor
+ * that takes a single {@code int} argument for the initial capacity.
  * </p>
  *
  * @see LogEvent#getContextData()
@@ -51,7 +54,8 @@ public class ContextDataFactory {
     private static final MethodHandle DEFAULT_CONSTRUCTOR = createDefaultConstructor(CACHED_CLASS);
     private static final MethodHandle INITIAL_CAPACITY_CONSTRUCTOR = createInitialCapacityConstructor(CACHED_CLASS);
 
-    private static final StringMap EMPTY_STRING_MAP = createContextData(1);
+    private static final StringMap EMPTY_STRING_MAP = createContextData(0);
+
     static {
         EMPTY_STRING_MAP.freeze();
     }
@@ -61,7 +65,7 @@ public class ContextDataFactory {
             return null;
         }
         try {
-            return LoaderUtil.loadClass(className).asSubclass(StringMap.class);
+            return Loader.loadClass(className).asSubclass(IndexedStringMap.class);
         } catch (final Exception any) {
             return null;
         }
@@ -94,7 +98,7 @@ public class ContextDataFactory {
             return new SortedArrayStringMap();
         }
         try {
-            return (StringMap) DEFAULT_CONSTRUCTOR.invoke();
+            return (IndexedStringMap) DEFAULT_CONSTRUCTOR.invoke();
         } catch (final Throwable ignored) {
             return new SortedArrayStringMap();
         }
@@ -105,18 +109,33 @@ public class ContextDataFactory {
             return new SortedArrayStringMap(initialCapacity);
         }
         try {
-            return (StringMap) INITIAL_CAPACITY_CONSTRUCTOR.invoke(initialCapacity);
+            return (IndexedStringMap) INITIAL_CAPACITY_CONSTRUCTOR.invoke(initialCapacity);
         } catch (final Throwable ignored) {
             return new SortedArrayStringMap(initialCapacity);
         }
     }
 
+    public static StringMap createContextData(final Map<String, String> context) {
+        final StringMap contextData = createContextData(context.size());
+        for (final Entry<String, String> entry : context.entrySet()) {
+            contextData.putValue(entry.getKey(), entry.getValue());
+        }
+        return contextData;
+    }
+
+    public static StringMap createContextData(final ReadOnlyStringMap readOnlyStringMap) {
+        final StringMap contextData = createContextData(readOnlyStringMap.size());
+        contextData.putAll(readOnlyStringMap);
+        return contextData;
+    }
+
     /**
-     * An empty pre-frozen StringMap. The returned object may be shared.
+     * An empty pre-frozen IndexedStringMap. The returned object may be shared.
      *
-     * @return an empty pre-frozen StringMap
+     * @return an empty pre-frozen IndexedStringMap
      */
     public static StringMap emptyFrozenContextData() {
         return EMPTY_STRING_MAP;
     }
+
 }
