@@ -16,25 +16,30 @@
  */
 package org.apache.logging.log4j.core.layout;
 
+import java.io.UnsupportedEncodingException;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
+
 import org.apache.logging.log4j.core.LogEvent;
 import org.apache.logging.log4j.core.StringLayout;
 import org.apache.logging.log4j.core.config.Configuration;
 import org.apache.logging.log4j.core.config.LoggerConfig;
+import org.apache.logging.log4j.core.config.plugins.PluginBuilderAttribute;
+import org.apache.logging.log4j.core.config.plugins.PluginElement;
 import org.apache.logging.log4j.core.impl.DefaultLogEventFactory;
 import org.apache.logging.log4j.core.util.Constants;
 import org.apache.logging.log4j.core.util.StringEncoder;
+import org.apache.logging.log4j.spi.AbstractLogger;
 import org.apache.logging.log4j.util.PropertiesUtil;
+import org.apache.logging.log4j.util.StringBuilders;
 import org.apache.logging.log4j.util.Strings;
 
-import java.io.UnsupportedEncodingException;
-import java.nio.charset.Charset;
-import java.nio.charset.StandardCharsets;
-
 /**
  * Abstract base class for Layouts that result in a String.
  * <p>
  * Since 2.4.1, this class has custom logic to convert ISO-8859-1 or US-ASCII Strings to byte[] arrays to improve
  * performance: all characters are simply cast to bytes.
+ * </p>
  */
 /*
  * Implementation note: prefer String.getBytes(String) to String.getBytes(Charset) for performance reasons. See
@@ -42,6 +47,46 @@ import java.nio.charset.StandardCharsets;
  */
 public abstract class AbstractStringLayout extends AbstractLayout<String> implements StringLayout {
 
+    public abstract static class Builder<B extends Builder<B>> extends AbstractLayout.Builder<B> {
+
+        @PluginBuilderAttribute(value = "charset")
+        private Charset charset;
+
+        @PluginElement("footerSerializer")
+        private Serializer footerSerializer;
+
+        @PluginElement("headerSerializer")
+        private Serializer headerSerializer;
+
+        public Charset getCharset() {
+            return charset;
+        }
+
+        public Serializer getFooterSerializer() {
+            return footerSerializer;
+        }
+
+        public Serializer getHeaderSerializer() {
+            return headerSerializer;
+        }
+
+        public B setCharset(final Charset charset) {
+            this.charset = charset;
+            return asBuilder();
+        }
+
+        public B setFooterSerializer(final Serializer footerSerializer) {
+            this.footerSerializer = footerSerializer;
+            return asBuilder();
+        }
+
+        public B setHeaderSerializer(final Serializer headerSerializer) {
+            this.headerSerializer = headerSerializer;
+            return asBuilder();
+        }
+
+    }
+
     public interface Serializer {
         String toSerializable(final LogEvent event);
     }
@@ -70,6 +115,10 @@ public abstract class AbstractStringLayout extends AbstractLayout<String> implem
      * @return a {@code StringBuilder}
      */
     protected static StringBuilder getStringBuilder() {
+        if (AbstractLogger.getRecursionDepth() > 1) { // LOG4J2-2368
+            // Recursive logging may clobber the cached StringBuilder.
+            return new StringBuilder(DEFAULT_STRING_BUILDER_SIZE);
+        }
         StringBuilder result = threadLocal.get();
         if (result == null) {
             result = new StringBuilder(DEFAULT_STRING_BUILDER_SIZE);
@@ -97,17 +146,14 @@ public abstract class AbstractStringLayout extends AbstractLayout<String> implem
     }
 
     protected static void trimToMaxSize(final StringBuilder stringBuilder) {
-        if (stringBuilder.length() > MAX_STRING_BUILDER_SIZE) {
-            stringBuilder.setLength(MAX_STRING_BUILDER_SIZE);
-            stringBuilder.trimToSize();
-        }
+        StringBuilders.trimToMaxSize(stringBuilder, MAX_STRING_BUILDER_SIZE);
     }
 
     private Encoder<StringBuilder> textEncoder;
     /**
      * The charset for the formatted message.
      */
-    // LOG4J2-1099: charset cannot be final due to serialization needs, so we serialize as charset name instead
+    // LOG4J2-1099: Charset cannot be final due to serialization needs, so we serialize as Charset name instead
     private transient Charset charset;
 
     private final String charsetName;
