@@ -551,9 +551,9 @@ public final class PatternLayout extends AbstractStringLayout {
         }
 
         private boolean useAnsiEscapeCodes() {
-            PropertiesUtil propertiesUtil = PropertiesUtil.getProperties();
-            boolean isPlatformSupportsAnsi = !propertiesUtil.isOsWindows();
-            boolean isJansiRequested = !propertiesUtil.getBooleanProperty("log4j.skipJansi", true);
+            final PropertiesUtil propertiesUtil = PropertiesUtil.getProperties();
+            final boolean isPlatformSupportsAnsi = !propertiesUtil.isOsWindows();
+            final boolean isJansiRequested = !propertiesUtil.getBooleanProperty("log4j.skipJansi", true);
             return isPlatformSupportsAnsi || isJansiRequested;
         }
 
@@ -661,4 +661,8 @@ public final class PatternLayout extends AbstractStringLayout {
                 alwaysWriteExceptions, disableAnsi, noConsoleNoAnsi, header, footer);
         }
     }
+
+    public Serializer getEventSerializer() {
+        return eventSerializer;
+    }
 }
