@@ -27,6 +27,7 @@ import org.apache.logging.log4j.core.config.Configuration;
 import org.apache.logging.log4j.core.config.plugins.Plugin;
 import org.apache.logging.log4j.core.impl.ThrowableFormatOptions;
 import org.apache.logging.log4j.core.layout.PatternLayout;
+import org.apache.logging.log4j.core.util.StringBuilderWriter;
 import org.apache.logging.log4j.util.Strings;
 
 
@@ -39,11 +40,16 @@ import org.apache.logging.log4j.util.Strings;
 @ConverterKeys({ "ex", "throwable", "exception" })
 public class ThrowablePatternConverter extends LogEventPatternConverter {
 
+    /**
+     * Lists {@link PatternFormatter}s for the suffix attribute.
+     */
     protected final List<PatternFormatter> formatters;
     private String rawOption;
+    private final boolean subShortOption;
+    private final boolean nonStandardLineSeparator;
 
     /**
-     * The number of lines to write.
+     * Options.
      */
     protected final ThrowableFormatOptions options;
 
@@ -62,35 +68,40 @@ public class ThrowablePatternConverter extends LogEventPatternConverter {
         }
         if (this.options.getSuffix() != null) {
             final PatternParser parser = PatternLayout.createPatternParser(config);
-            final List<PatternFormatter> parsedFormatters = parser.parse(this.options.getSuffix());
+            final List<PatternFormatter> parsedSuffixFormatters = parser.parse(this.options.getSuffix());
             // filter out nested formatters that will handle throwable
-            boolean hasThrowableFormatter = false;
-            for (final PatternFormatter formatter : parsedFormatters) {
-                if (formatter.handlesThrowable()) {
-                    hasThrowableFormatter = true;
+            boolean hasThrowableSuffixFormatter = false;
+            for (final PatternFormatter suffixFormatter : parsedSuffixFormatters) {
+                if (suffixFormatter.handlesThrowable()) {
+                    hasThrowableSuffixFormatter = true;
                 }
             }
-            if (!hasThrowableFormatter) {
-                this.formatters = parsedFormatters;
+            if (!hasThrowableSuffixFormatter) {
+                this.formatters = parsedSuffixFormatters;
             } else {
-                final List<PatternFormatter> formatters = new ArrayList<>();
-                for (final PatternFormatter formatter : parsedFormatters) {
-                    if (!formatter.handlesThrowable()) {
-                        formatters.add(formatter);
+                final List<PatternFormatter> suffixFormatters = new ArrayList<>();
+                for (final PatternFormatter suffixFormatter : parsedSuffixFormatters) {
+                    if (!suffixFormatter.handlesThrowable()) {
+                        suffixFormatters.add(suffixFormatter);
                     }
                 }
-                this.formatters = formatters;
+                this.formatters = suffixFormatters;
             }
         } else {
             this.formatters = Collections.emptyList();
         }
-
+        subShortOption = ThrowableFormatOptions.MESSAGE.equalsIgnoreCase(rawOption) ||
+                ThrowableFormatOptions.LOCALIZED_MESSAGE.equalsIgnoreCase(rawOption) ||
+                ThrowableFormatOptions.FILE_NAME.equalsIgnoreCase(rawOption) ||
+                ThrowableFormatOptions.LINE_NUMBER.equalsIgnoreCase(rawOption) ||
+                ThrowableFormatOptions.METHOD_NAME.equalsIgnoreCase(rawOption) ||
+                ThrowableFormatOptions.CLASS_NAME.equalsIgnoreCase(rawOption);
+        nonStandardLineSeparator = !Strings.LINE_SEPARATOR.equals(this.options.getSeparator());
     }
 
     /**
      * Gets an instance of the class.
      *
-     *
      * @param config
      * @param options pattern options, may be null.  If first element is "short",
      *                only the first line of the throwable will be formatted.
@@ -107,7 +118,7 @@ public class ThrowablePatternConverter extends LogEventPatternConverter {
     public void format(final LogEvent event, final StringBuilder buffer) {
         final Throwable t = event.getThrown();
 
-        if (isSubShortOption()) {
+        if (subShortOption) {
             formatSubShortOption(t, getSuffix(event), buffer);
         }
         else if (t != null && options.anyLines()) {
@@ -115,15 +126,6 @@ public class ThrowablePatternConverter extends LogEventPatternConverter {
         }
     }
 
-    private boolean isSubShortOption() {
-        return ThrowableFormatOptions.MESSAGE.equalsIgnoreCase(rawOption) ||
-                ThrowableFormatOptions.LOCALIZED_MESSAGE.equalsIgnoreCase(rawOption) ||
-                ThrowableFormatOptions.FILE_NAME.equalsIgnoreCase(rawOption) ||
-                ThrowableFormatOptions.LINE_NUMBER.equalsIgnoreCase(rawOption) ||
-                ThrowableFormatOptions.METHOD_NAME.equalsIgnoreCase(rawOption) ||
-                ThrowableFormatOptions.CLASS_NAME.equalsIgnoreCase(rawOption);
-    }
-
     private void formatSubShortOption(final Throwable t, final String suffix, final StringBuilder buffer) {
         StackTraceElement[] trace;
         StackTraceElement throwingMethod = null;
@@ -172,32 +174,29 @@ public class ThrowablePatternConverter extends LogEventPatternConverter {
     }
 
     private void formatOption(final Throwable throwable, final String suffix, final StringBuilder buffer) {
-        final StringWriter w = new StringWriter();
-
-        throwable.printStackTrace(new PrintWriter(w));
         final int len = buffer.length();
         if (len > 0 && !Character.isWhitespace(buffer.charAt(len - 1))) {
             buffer.append(' ');
         }
-        if (!options.allLines() || !Strings.LINE_SEPARATOR.equals(options.getSeparator()) || Strings.isNotBlank(suffix)) {
-            final StringBuilder sb = new StringBuilder();
+        if (!options.allLines() || nonStandardLineSeparator || Strings.isNotBlank(suffix)) {
+            final StringWriter w = new StringWriter();
+            throwable.printStackTrace(new PrintWriter(w));
+
             final String[] array = w.toString().split(Strings.LINE_SEPARATOR);
             final int limit = options.minLines(array.length) - 1;
             final boolean suffixNotBlank = Strings.isNotBlank(suffix);
             for (int i = 0; i <= limit; ++i) {
-                sb.append(array[i]);
+                buffer.append(array[i]);
                 if (suffixNotBlank) {
-                    sb.append(' ');
-                    sb.append(suffix);
+                    buffer.append(' ');
+                    buffer.append(suffix);
                 }
                 if (i < limit) {
-                    sb.append(options.getSeparator());
+                    buffer.append(options.getSeparator());
                 }
             }
-            buffer.append(sb.toString());
-
         } else {
-            buffer.append(w.toString());
+            throwable.printStackTrace(new PrintWriter(new StringBuilderWriter(buffer)));
         }
     }
 
@@ -212,6 +211,9 @@ public class ThrowablePatternConverter extends LogEventPatternConverter {
     }
 
     protected String getSuffix(final LogEvent event) {
+        if (formatters.isEmpty()) {
+            return Strings.EMPTY;
+        }
         //noinspection ForLoopReplaceableByForEach
         final StringBuilder toAppendTo = new StringBuilder();
         for (int i = 0, size = formatters.size(); i <  size; i++) {
@@ -219,4 +221,8 @@ public class ThrowablePatternConverter extends LogEventPatternConverter {
         }
         return toAppendTo.toString();
     }
+
+    public ThrowableFormatOptions getOptions() {
+        return options;
+    }
 }
