@@ -93,10 +93,8 @@ public class OutputStreamAppenderTest {
         final Configuration config = ctx.getConfiguration();
         // @formatter:off
         final Appender appender = FileAppender.newBuilder()
-            .withFileName("target/" + getClass().getName() + ".log")
-            .withAppend(false)
-            .withName("File")
-            .withIgnoreExceptions(false)
+        .withFileName("target/" + getClass().getName() + ".log")
+        .withAppend(false).setName("File").setIgnoreExceptions(false)
             .withBufferedIo(false)
             .withBufferSize(4000)
             .setConfiguration(config)
