@@ -20,11 +20,14 @@ import static org.apache.logging.log4j.hamcrest.Descriptors.that;
 import static org.apache.logging.log4j.hamcrest.FileMatchers.hasName;
 import static org.hamcrest.Matchers.endsWith;
 import static org.hamcrest.Matchers.hasItemInArray;
+import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
 
 import java.io.File;
+import java.util.Arrays;
+import java.util.Random;
 
 import org.apache.logging.log4j.Logger;
 import org.apache.logging.log4j.junit.LoggerContextRule;
@@ -56,14 +59,38 @@ public class RollingAppenderTimeAndSizeTest {
 
     @Test
     public void testAppender() throws Exception {
-        for (int i=0; i < 100; ++i) {
-            logger.debug("This is test message number " + i);
-        }
-        Thread.sleep(50);
-        final File dir = new File(DIR);
-        assertTrue("Directory not created", dir.exists() && dir.listFiles().length > 0);
-        final File[] files = dir.listFiles();
-        assertNotNull(files);
-        assertThat(files, hasItemInArray(that(hasName(that(endsWith(".gz"))))));
+		Random rand = new Random();
+		for (int j=0; j < 100; ++j) {
+			int count = rand.nextInt(100);
+			for (int i = 0; i < count; ++i) {
+				logger.debug("This is test message number " + i);
+			}
+			Thread.sleep(rand.nextInt(50));
+		}
+		Thread.sleep(50);
+		final File dir = new File(DIR);
+		assertTrue("Directory not created", dir.exists() && dir.listFiles().length > 0);
+		final File[] files = dir.listFiles();
+		Arrays.sort(files);
+		assertNotNull(files);
+		assertThat(files, hasItemInArray(that(hasName(that(endsWith(".log"))))));
+		int found = 0;
+		int fileCounter = 0;
+		String previous = "";
+		for (final File file: files) {
+			final String actual = file.getName();
+			StringBuilder padding = new StringBuilder();
+			String length = Long.toString(file.length());
+			for (int i = length.length(); i < 10; ++i) {
+				padding.append(" ");
+			}
+			final String[] fileParts = actual.split("_|\\.");
+			fileCounter = previous.equals(fileParts[1]) ? ++fileCounter : 1;
+			previous = fileParts[1];
+			assertEquals("Incorrect file name. Expected counter value of " + fileCounter + " in " + actual,
+				Integer.toString(fileCounter), fileParts[2]);
+
+
+		}
     }
 }
