@@ -17,6 +17,10 @@
 
 package org.apache.logging.log4j.core.config;
 
+import org.apache.logging.log4j.categories.Configurations;
+import org.junit.experimental.categories.Category;
+
+@Category(Configurations.Json.class)
 public class JiraLog4j2_1100JsonTest extends AbstractLog4j2_1100Test {
 
     @Override
