@@ -28,12 +28,16 @@ import org.apache.logging.log4j.Level;
 import org.apache.logging.log4j.MarkerManager;
 import org.apache.logging.log4j.ThreadContext;
 import org.apache.logging.log4j.core.LogEvent;
+import org.apache.logging.log4j.message.Message;
 import org.apache.logging.log4j.message.ParameterizedMessage;
+import org.apache.logging.log4j.message.ReusableMessageFactory;
 import org.apache.logging.log4j.message.SimpleMessage;
+import org.apache.logging.log4j.util.FilteredObjectInputStream;
 import org.apache.logging.log4j.util.SortedArrayStringMap;
 import org.apache.logging.log4j.util.StringMap;
 import org.apache.logging.log4j.spi.MutableThreadContextStack;
 import org.junit.Assert;
+import org.junit.BeforeClass;
 import org.junit.Test;
 
 import static org.junit.Assert.*;
@@ -45,6 +49,8 @@ public class MutableLogEventTest {
     private static final StringMap CONTEXT_DATA = createContextData();
     private static final ThreadContext.ContextStack STACK = new MutableThreadContextStack(Arrays.asList("abc", "xyz"));
 
+    static boolean useObjectInputStream = false;
+
     private static StringMap createContextData() {
         final StringMap result = new SortedArrayStringMap();
         result.putValue("a", "1");
@@ -52,6 +58,16 @@ public class MutableLogEventTest {
         return result;
     }
 
+    @BeforeClass
+    public static void setupClass() {
+        try {
+            Class.forName("java.io.ObjectInputFilter");
+            useObjectInputStream = true;
+        } catch (final ClassNotFoundException ex) {
+            // Ignore the exception
+        }
+    }
+
     @Test
     public void testToImmutable() {
         final LogEvent logEvent = new MutableLogEvent();
@@ -98,6 +114,78 @@ public class MutableLogEventTest {
         assertEquals("millis", source.getTimeMillis(), mutable.getTimeMillis());
     }
 
+    @Test
+    public void testInitFromReusableCopiesFormatString() {
+        final Message message = ReusableMessageFactory.INSTANCE.newMessage("msg in a {}", "bottle");
+        final Log4jLogEvent source = Log4jLogEvent.newBuilder() //
+                .setContextData(CONTEXT_DATA) //
+                .setContextStack(STACK) //
+                .setEndOfBatch(true) //
+                .setIncludeLocation(true) //
+                .setLevel(Level.FATAL) //
+                .setLoggerFqcn("a.b.c.d.e") //
+                .setLoggerName("my name is Logger") //
+                .setMarker(MarkerManager.getMarker("on your marks")) //
+                .setMessage(message) //
+                .setNanoTime(1234567) //
+                .setSource(new StackTraceElement("myclass", "mymethod", "myfile", 123)) //
+                .setThreadId(100).setThreadName("threadname").setThreadPriority(10) //
+                .setThrown(new RuntimeException("run")) //
+                .setTimeMillis(987654321)
+                .build();
+        final MutableLogEvent mutable = new MutableLogEvent();
+        mutable.initFrom(source);
+        assertEquals("format", "msg in a {}", mutable.getFormat());
+        assertEquals("formatted", "msg in a bottle", mutable.getFormattedMessage());
+        assertEquals("parameters", new String[] {"bottle"}, mutable.getParameters());
+        final Message memento = mutable.memento();
+        assertEquals("format", "msg in a {}", memento.getFormat());
+        assertEquals("formatted", "msg in a bottle", memento.getFormattedMessage());
+        assertEquals("parameters", new String[] {"bottle"}, memento.getParameters());
+
+        final Message eventMementoMessage = mutable.createMemento().getMessage();
+        assertEquals("format", "msg in a {}", eventMementoMessage.getFormat());
+        assertEquals("formatted", "msg in a bottle", eventMementoMessage.getFormattedMessage());
+        assertEquals("parameters", new String[] {"bottle"}, eventMementoMessage.getParameters());
+
+        final Message log4JLogEventMessage = new Log4jLogEvent.Builder(mutable).build().getMessage();
+        assertEquals("format", "msg in a {}", log4JLogEventMessage.getFormat());
+        assertEquals("formatted", "msg in a bottle", log4JLogEventMessage.getFormattedMessage());
+        assertEquals("parameters", new String[] {"bottle"}, log4JLogEventMessage.getParameters());
+    }
+
+    @Test
+    public void testInitFromReusableObjectCopiesParameter() {
+        final Object param = new Object();
+        final Message message = ReusableMessageFactory.INSTANCE.newMessage(param);
+        final Log4jLogEvent source = Log4jLogEvent.newBuilder()
+                .setContextData(CONTEXT_DATA)
+                .setContextStack(STACK)
+                .setEndOfBatch(true)
+                .setIncludeLocation(true)
+                .setLevel(Level.FATAL)
+                .setLoggerFqcn("a.b.c.d.e")
+                .setLoggerName("my name is Logger")
+                .setMarker(MarkerManager.getMarker("on your marks"))
+                .setMessage(message)
+                .setNanoTime(1234567)
+                .setSource(new StackTraceElement("myclass", "mymethod", "myfile", 123))
+                .setThreadId(100).setThreadName("threadname")
+                .setThreadPriority(10)
+                .setThrown(new RuntimeException("run"))
+                .setTimeMillis(987654321)
+                .build();
+        final MutableLogEvent mutable = new MutableLogEvent();
+        mutable.initFrom(source);
+        assertNull("format", mutable.getFormat());
+        assertEquals("formatted", param.toString(), mutable.getFormattedMessage());
+        assertEquals("parameters", new Object[] {param}, mutable.getParameters());
+        final Message memento = mutable.memento();
+        assertNull("format", memento.getFormat());
+        assertEquals("formatted", param.toString(), memento.getFormattedMessage());
+        assertEquals("parameters", new Object[] {param}, memento.getParameters());
+    }
+
     @Test
     public void testClear() {
         final MutableLogEvent mutable = new MutableLogEvent();
@@ -278,7 +366,8 @@ public class MutableLogEventTest {
 
     private Log4jLogEvent deserialize(final byte[] binary) throws IOException, ClassNotFoundException {
         final ByteArrayInputStream inArr = new ByteArrayInputStream(binary);
-        final ObjectInputStream in = new ObjectInputStream(inArr);
+        final ObjectInputStream in = useObjectInputStream ? new ObjectInputStream(inArr) :
+                new FilteredObjectInputStream(inArr);
         final Log4jLogEvent result = (Log4jLogEvent) in.readObject();
         return result;
     }
