@@ -26,7 +26,7 @@ public class LevelMixInJsonTest extends LevelMixInTest {
 
     @Override
     protected ObjectMapper newObjectMapper() {
-        return new Log4jJsonObjectMapper(false, true, false);
+        return new Log4jJsonObjectMapper(false, true, false, false);
     }
 
 }
