@@ -17,6 +17,12 @@
 
 package org.apache.logging.log4j.core.util.datetime;
 
+import static org.apache.logging.log4j.core.util.datetime.FixedDateFormat.FixedFormat.DEFAULT;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
@@ -27,9 +33,6 @@ import java.util.concurrent.TimeUnit;
 import org.apache.logging.log4j.core.util.datetime.FixedDateFormat.FixedFormat;
 import org.junit.Test;
 
-import static org.apache.logging.log4j.core.util.datetime.FixedDateFormat.FixedFormat.*;
-import static org.junit.Assert.*;
-
 /**
  * Tests {@link FixedDateFormat}.
  */
@@ -156,12 +159,16 @@ public class FixedDateFormatTest {
         final long start = now - TimeUnit.HOURS.toMillis(25);
         final long end = now + TimeUnit.HOURS.toMillis(25);
         for (final FixedFormat format : FixedFormat.values()) {
-            final SimpleDateFormat simpleDF = new SimpleDateFormat(format.getPattern(), Locale.getDefault());
+            final String pattern = format.getPattern();
+            if (containsNanos(format) || format.getFixedTimeZoneFormat() != null) {
+                continue; // cannot compile precise timestamp formats with SimpleDateFormat
+            }
+            final SimpleDateFormat simpleDF = new SimpleDateFormat(pattern, Locale.getDefault());
             final FixedDateFormat customTF = new FixedDateFormat(format, TimeZone.getDefault());
             for (long time = start; time < end; time += 12345) {
                 final String actual = customTF.format(time);
                 final String expected = simpleDF.format(new Date(time));
-                assertEquals(format + "(" + format.getPattern() + ")" + "/" + time, expected, actual);
+                assertEquals(format + "(" + pattern + ")" + "/" + time, expected, actual);
             }
         }
     }
@@ -172,12 +179,16 @@ public class FixedDateFormatTest {
         final long start = now - TimeUnit.HOURS.toMillis(25);
         final long end = now + TimeUnit.HOURS.toMillis(25);
         for (final FixedFormat format : FixedFormat.values()) {
-            final SimpleDateFormat simpleDF = new SimpleDateFormat(format.getPattern(), Locale.getDefault());
+            final String pattern = format.getPattern();
+            if (containsNanos(format) || format.getFixedTimeZoneFormat() != null) {
+                continue; // cannot compile precise timestamp formats with SimpleDateFormat
+            }
+            final SimpleDateFormat simpleDF = new SimpleDateFormat(pattern, Locale.getDefault());
             final FixedDateFormat customTF = new FixedDateFormat(format, TimeZone.getDefault());
             for (long time = end; time > start; time -= 12345) {
                 final String actual = customTF.format(time);
                 final String expected = simpleDF.format(new Date(time));
-                assertEquals(format + "(" + format.getPattern() + ")" + "/" + time, expected, actual);
+                assertEquals(format + "(" + pattern + ")" + "/" + time, expected, actual);
             }
         }
     }
@@ -189,13 +200,19 @@ public class FixedDateFormatTest {
         final long end = now + TimeUnit.HOURS.toMillis(25);
         final char[] buffer = new char[128];
         for (final FixedFormat format : FixedFormat.values()) {
-            final SimpleDateFormat simpleDF = new SimpleDateFormat(format.getPattern(), Locale.getDefault());
+            final String pattern = format.getPattern();
+            if (containsNanos(format) || format.getFixedTimeZoneFormat() != null) {
+                // cannot compile precise timestamp formats with SimpleDateFormat
+                // This format() API not include the TZ
+                continue;
+            }
+            final SimpleDateFormat simpleDF = new SimpleDateFormat(pattern, Locale.getDefault());
             final FixedDateFormat customTF = new FixedDateFormat(format, TimeZone.getDefault());
             for (long time = start; time < end; time += 12345) {
                 final int length = customTF.format(time, buffer, 23);
                 final String actual = new String(buffer, 23, length);
                 final String expected = simpleDF.format(new Date(time));
-                assertEquals(format + "(" + format.getPattern() + ")" + "/" + time, expected, actual);
+                assertEquals(format + "(" + pattern + ")" + "/" + time, expected, actual);
             }
         }
     }
@@ -207,13 +224,17 @@ public class FixedDateFormatTest {
         final long end = now + TimeUnit.HOURS.toMillis(25);
         final char[] buffer = new char[128];
         for (final FixedFormat format : FixedFormat.values()) {
-            final SimpleDateFormat simpleDF = new SimpleDateFormat(format.getPattern(), Locale.getDefault());
+            final String pattern = format.getPattern();
+            if (pattern.endsWith("n") || pattern.matches(".+n+X*") || pattern.matches(".+n+Z*") || format.getFixedTimeZoneFormat() != null) {
+                continue; // cannot compile precise timestamp formats with SimpleDateFormat
+            }
+            final SimpleDateFormat simpleDF = new SimpleDateFormat(pattern, Locale.getDefault());
             final FixedDateFormat customTF = new FixedDateFormat(format, TimeZone.getDefault());
             for (long time = end; time > start; time -= 12345) {
                 final int length = customTF.format(time, buffer, 23);
                 final String actual = new String(buffer, 23, length);
                 final String expected = simpleDF.format(new Date(time));
-                assertEquals(format + "(" + format.getPattern() + ")" + "/" + time, expected, actual);
+                assertEquals(format + "(" + pattern + ")" + "/" + time, expected, actual);
             }
         }
     }
@@ -348,6 +369,12 @@ public class FixedDateFormatTest {
             calendar.add(Calendar.HOUR_OF_DAY, 1);
         }
     }
+    
+    private boolean containsNanos(final FixedFormat fixedFormat) {
+        final String pattern = fixedFormat.getPattern();
+        return pattern.endsWith("n") || pattern.matches(".+n+X*") || pattern.matches(".+n+Z*");
+    }
+    
     /**
      * This test case validates date pattern before and after DST
      * Base Date : 12 Mar 2017
@@ -362,12 +389,16 @@ public class FixedDateFormatTest {
         final long end = now + TimeUnit.HOURS.toMillis(1);
 
         for (final FixedFormat format : FixedFormat.values()) {
-            final SimpleDateFormat simpleDF = new SimpleDateFormat(format.getPattern(), Locale.getDefault());
+            final String pattern = format.getPattern();
+            if (containsNanos(format) || format.getFixedTimeZoneFormat() != null) {
+                continue; // cannot compile precise timestamp formats with SimpleDateFormat
+            }
+            final SimpleDateFormat simpleDF = new SimpleDateFormat(pattern, Locale.getDefault());
             final FixedDateFormat customTF = new FixedDateFormat(format, TimeZone.getDefault());
             for (long time = end; time > start; time -= 12345) {
                 final String actual = customTF.format(time);
                 final String expected = simpleDF.format(new Date(time));
-                assertEquals(format + "(" + format.getPattern() + ")" + "/" + time, expected, actual);
+                assertEquals(format + "(" + pattern + ")" + "/" + time, expected, actual);
             }
         }
     }
