@@ -48,7 +48,7 @@ public class LoggerContextRule implements TestRule, LoggerContextAccessor {
     public static LoggerContextRule createShutdownTimeoutLoggerContextRule(final String config) {
         return new LoggerContextRule(config, 10, TimeUnit.SECONDS);
     }
-    
+
     private static final String SYS_PROP_KEY_CLASS_NAME = "org.apache.logging.log4j.junit.LoggerContextRule#ClassName";
     private static final String SYS_PROP_KEY_DISPLAY_NAME = "org.apache.logging.log4j.junit.LoggerContextRule#DisplayName";
     private final String configLocation;
@@ -145,8 +145,9 @@ public class LoggerContextRule implements TestRule, LoggerContextAccessor {
      *            the name of the Appender to look up.
      * @return the named Appender or {@code null} if it wasn't defined in the configuration.
      */
-    public Appender getAppender(final String name) {
-        return getConfiguration().getAppenders().get(name);
+    @SuppressWarnings("unchecked") // Assume the call site knows what it is doing.
+	public <T extends Appender> T getAppender(final String name) {
+        return (T) getConfiguration().getAppenders().get(name);
     }
 
     /**
@@ -277,7 +278,7 @@ public class LoggerContextRule implements TestRule, LoggerContextAccessor {
     public void reconfigure() {
         loggerContext.reconfigure();
     }
-    
+
     @Override
     public String toString() {
         final StringBuilder builder = new StringBuilder();
