@@ -19,6 +19,7 @@ package org.apache.logging.log4j.test.layout;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 
+import org.apache.logging.log4j.core.Core;
 import org.apache.logging.log4j.core.LogEvent;
 import org.apache.logging.log4j.core.config.plugins.Plugin;
 import org.apache.logging.log4j.core.config.plugins.PluginFactory;
@@ -28,7 +29,7 @@ import org.apache.logging.log4j.util.Strings;
 /**
  *
  */
-@Plugin(name = "BasicLayout", category = "Core", elementType = "layout", printObject = true)
+@Plugin(name = "BasicLayout", category = Core.CATEGORY_NAME, elementType = "layout", printObject = true)
 public class BasicLayout extends AbstractStringLayout {
 
     private static final String HEADER = "Header" + Strings.LINE_SEPARATOR;
